package com.muyu.common.caffeine.bean;


import com.github.benmanes.caffeine.cache.Cache;
import com.github.benmanes.caffeine.cache.Caffeine;
import org.springframework.cache.CacheManager;
import org.springframework.cache.caffeine.CaffeineCache;
import org.springframework.cache.support.SimpleCacheManager;
import org.springframework.context.annotation.Bean;
import org.springframework.stereotype.Component;

import java.util.ArrayList;


/**
 * @Author: 胡杨
 * @Name: CaffeineCacheConfig
 * @Description: Caffeine管理器
 * @CreatedDate: 2024/9/26 上午11:52
 * @FilePath: com.muyu.common.caffeine.config
 */
@Component
public class CaffeineManager {
    /**
     * 创建缓存管理器
     * @return  缓存管理器实例
     */
    @Bean
    public CacheManager cacheManager() {
        SimpleCacheManager cacheManager = new SimpleCacheManager();
        cacheManager.setCaches(getCaches());
        return cacheManager;
    }


    private ArrayList<CaffeineCache> getCaches() {
        ArrayList<CaffeineCache> caches = new ArrayList<>();
        // 故障信息缓存
        caches.add(new CaffeineCache("fault", Caffeine.newBuilder().build()));
        // 围栏信息缓存
        caches.add(new CaffeineCache("fence", Caffeine.newBuilder().build()));
        // 预警策略规则缓存
        caches.add(new CaffeineCache("warming", Caffeine.newBuilder().build()));
        return caches;
    }


}
